# WellsFargo API

WellsFargo API wrapper.

Supported endpoints:

- Token generation
- Wires and ACH payments

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'wells_fargo-api'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install wells_fargo-api

## Usage

Initialize `WellsFargo::API` with required credentials:

```ruby
require 'wells_fargo-api'

client = WellsFargo::API.new(
  'https://api.wellsfargo.com',
  client_cert: 'path_to_certificate',
  client_key: 'path_to_private_key',
  consumer_key: 'consumer_key',
  consumer_secret: 'consumer_secret',
  gateway_company_id: 'gateway_company_id',
  gateway_entity_id: 'gateway_entity_id'
)
```

Then make requests using simple API

```ruby
response = client.wires.create_payment(payload)

if response.success?
  puts response[:payment_id] # easy access to parsed data
else
  puts response[:errors]
end
```

If you're using Rails, it's possible to put configuration into an initializer file:

```ruby
WellsFargo.configure do |config|
  config.url = 'https://api.wellsfargo.com'
  config.client_cert = 'path_to_certificate'
  config.client_key = 'path_to_private_key'
  config.consumer_key = 'consumer_key'
  config.consumer_secret = 'consumer_secret'
  config.gateway_company_id = 'gateway_company_id'
  config.gateway_entity_id = 'gateway_entity_id'
end
```

And then access client object trough

```ruby
WellsFargo.client
```



## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/appodeal/wells_fargo-api. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## Code of Conduct

Everyone interacting in the WellsFargo project’s codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/appodeal/wells_fargo-api/blob/master/CODE_OF_CONDUCT.md).
